@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   PGSBOX 3.2 - a non-linear coordinate axis plotter for PGPLOT.
+*   PGSBOX 3.3 - a non-linear coordinate axis plotter for PGPLOT.
 *   Copyright (C) 1997-2003, Mark Calabretta
 *
 *   This program is free software; you can redistribute it and/or modify it
@@ -26,12 +26,11 @@
 *                      AUSTRALIA
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: cpgtest.c,v 3.2 2003/09/09 07:52:48 mcalabre Exp $
+*   $Id: cpgtest.c,v 3.3 2003/10/22 08:56:52 mcalabre Exp $
 *=============================================================================
 *
 *   cpgtest
 *
-*   $Id: cpgtest.c,v 3.2 2003/09/09 07:52:48 mcalabre Exp $
 *---------------------------------------------------------------------------*/
 
 #include <math.h>
@@ -120,10 +119,12 @@ int main()
    cpgask(1);
    cpgpage();
 
+   wcs.flag = -1;
+
   /*--------------------------------------------------------------------------
-   * First example: longitude-velocity map.  The y-axis is regularly spaced in
-   * frequency but is to be labelled as a true relativistic velocity.  PGSBOX
-   * uses subroutine LNGVEL.  Features:
+   * Longitude-velocity map; the y-axis is regularly spaced in frequency but
+   * is to be labelled as a true relativistic velocity.
+   *    - PGSBOX uses subroutine LNGVEL.
    *    - Separable (i.e. orthogonal), non-linear coordinate system.
    *    - Automatic choice of coordinate increments.
    *    - Extraction of a common scaling factor.
@@ -190,10 +191,10 @@ int main()
    cpgpage();
 
   /*--------------------------------------------------------------------------
-   * Second example: azimuth-frequency scan.  This sort of output might be
-   * obtained from an antenna which scans in azimuth with a receiver which
-   * scans simultaneously in frequency.  PGSBOX uses subroutine FSCAN.
-   * Features:
+   * Azimuth-frequency scan; this sort of output might be obtained from an
+   * antenna which scans in azimuth with a receiver which scans simultaneously
+   * in frequency.
+   *    - PGSBOX uses subroutine FSCAN.
    *    - Non-separable (i.e. non-orthogonal) non-linear coordinate system.
    *    - Automatic choice of what edges to label; results in labelling the
    *      bottom, left and right sides of the plot.
@@ -232,7 +233,7 @@ int main()
    opt[1] = 'L';
 
    /* Normal size lettering. */
-   cpgsch(1.0*scl);
+   cpgsch(1.0f*scl);
 
    /* Draw full grid lines. */
    cpgsci(1);
@@ -253,8 +254,8 @@ int main()
 
 
   /*--------------------------------------------------------------------------
-   * Third example: Z versus time plot.  PGSBOX uses subroutine PGCRFN.
-   * Features:
+   * Z versus time plot.
+   *    - PGSBOX uses subroutine PGCRFN.
    *    - Separable (i.e. orthogonal), non-linear coordinate system.
    *    - Use of function PGCRFN for separable axis types.
    *    - Automatic choice of what edges to label; results in labelling the
@@ -289,7 +290,7 @@ int main()
    opt[1] = ' ';
 
    /* Normal size lettering. */
-   cpgsch(1.0*scl);
+   cpgsch(1.0f*scl);
 
    /* Draw ticks for the first coordinate, grid lines for the second. */
    cpgsci(1);
@@ -303,13 +304,13 @@ int main()
       pgcrfn_, 8, 2, 4, fcode[0], nliprm, nldprm, 256, &ic, cache, &ierr);
 
    /* Draw the frame. */
-   cpgbox("BC", 0.0, 0, "BC", 0.0, 0);
+   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
    cpgpage();
 
   /*--------------------------------------------------------------------------
-   * Fourth example: A simple SIN projection near the south celestial pole.
-   * PGSBOX uses subroutine PGWCSL to interface to WCSLIB.  Features:
+   * Simple SIN projection near the south celestial pole.
+   *    - PGSBOX uses subroutine PGWCSL to interface to WCSLIB.
    *    - Non-separable (i.e. non-orthogonal) curvilinear coordinate system.
    *    - Demonstrate parameter definition for PGWCSL.
    *    - Discovery of grid lines which do not cross any axis.
@@ -328,7 +329,6 @@ int main()
    *      time format.
    *------------------------------------------------------------------------*/
 
-   wcs.flag = -1;
    status = wcsini(1, 2, &wcs);
 
    /* Set projection type to SIN. */
@@ -366,7 +366,7 @@ int main()
    opt[1] = 'E';
 
    /* Compact lettering. */
-   cpgsch(0.8*scl);
+   cpgsch(0.8f*scl);
 
    /* Draw full grid lines. */
    cpgsci(1);
@@ -388,8 +388,8 @@ int main()
    cpgpage();
 
   /*-------------------------------------------------------------------------
-   * Fifth example: Conic equal area.  PGSBOX uses subroutine PGWCSL
-   * to interface to WCSLIB.  Features:
+   * Conic equal area projection.
+   *    - PGSBOX uses subroutine PGWCSL to interface to WCSLIB.
    *    - Non-separable (i.e. non-orthogonal) curvilinear coordinate system.
    *    - Coordinate system undefined in areas of the plot.
    *    - Demonstrate parameter definition for PGWCSL.
@@ -407,7 +407,7 @@ int main()
    *      degree format.
    *------------------------------------------------------------------------*/
 
-   status = wcsini(0, 2, &wcs);
+   status = wcsini(1, 2, &wcs);
 
    /* Set projection type to conic equal-area. */
    strcpy(wcs.ctype[0], "RA---COE");
@@ -444,7 +444,7 @@ int main()
    opt[1] = 'E';
 
    /* Reduced size lettering. */
-   cpgsch(0.8*scl);
+   cpgsch(0.8f*scl);
 
    /* Draw full grid lines. */
    gcode[0] = 2;
@@ -507,8 +507,8 @@ int main()
    cpgpage();
 
   /*--------------------------------------------------------------------------
-   * Sixth example: Polyconic with colour-coded grid.  PGSBOX uses subroutine
-   * PGWCSL to interface to WCSLIB.  Features:
+   * Polyconic projection with colour-coded grid.
+   *    - PGSBOX uses subroutine PGWCSL to interface to WCSLIB.
    *    - Non-separable (i.e. non-orthogonal) curvilinear coordinate system.
    *    - Coordinate system undefined in areas of the plot.
    *    - Demonstrate parameter definition for PGWCSL.
@@ -530,7 +530,7 @@ int main()
    *      time format.
    *------------------------------------------------------------------------*/
 
-   status = wcsini(0, 2, &wcs);
+   status = wcsini(1, 2, &wcs);
 
    /* Set projection type to polyconic. */
    strcpy(wcs.ctype[0], "RA---PCO");
@@ -565,7 +565,7 @@ int main()
    opt[1] = 'B';
 
    /* Reduced size lettering. */
-   cpgsch(0.9*scl);
+   cpgsch(0.9f*scl);
 
    /* Draw external (TIKLEN < 0) tick marks every 5 degrees. */
    gcode[0] = 1;
@@ -715,8 +715,8 @@ int main()
    cpgpage();
 
   /*--------------------------------------------------------------------------
-   * Seventh example: Plate Carree projection.  PGSBOX uses subroutine PGWCSL
-   * to interface to WCSLIB.  Features:
+   * Plate Carree projection.
+   *    - PGSBOX uses subroutine PGWCSL to interface to WCSLIB.
    *    - Rectangular image.
    *    - Dual coordinate grids.
    *    - Non-separable (i.e. non-orthogonal) curvilinear coordinate system.
@@ -747,7 +747,7 @@ int main()
    }
    cpgwnad(0.0f, 1.0f, 0.0f, ((float)naxis[1])/((float)naxis[0]));
 
-   status = wcsini(0, 2, &wcs);
+   status = wcsini(1, 2, &wcs);
 
    /* Set projection type to plate carree. */
    strcpy(wcs.ctype[0], "GLON-CAR");
@@ -789,7 +789,7 @@ int main()
    opt[1] = 'C';
 
    /* Reduced size lettering. */
-   cpgsch(0.8*scl);
+   cpgsch(0.8f*scl);
 
    /* Draw full grid lines. */
    gcode[0] = 2;
@@ -868,13 +868,86 @@ int main()
 
    /* Draw the frame. */
    cpgsci(1);
-   cpgbox("BC", 0.0, 0, "BC", 0.0, 0);
+   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
    cpgpage();
 
   /*--------------------------------------------------------------------------
-   * Eighth example: linear-linear plot with two types of alternative
-   * labelling.  PGSBOX uses subroutine PGCRFN.  Features:
+   * Plate Carree projection.
+   *    - PGSBOX uses subroutine PGWCSL to interface to WCSLIB.
+   *    - BLC, TRC unrelated to pixel coordinates.
+   *    - Demonstrate parameter definition for PGWCSL.
+   *    - Poles and 180 meridian projected along edges of the frame.
+   *    - Reduced size lettering.
+   *    - Manual and automatic choice of coordinate increments.
+   *    - Suppression of common zero minute and second fields in
+   *      sexagesimal time format.
+   *------------------------------------------------------------------------*/
+
+   blc[0] = -180.0;
+   blc[1] =  -90.0;
+   trc[0] =  180.0;
+   trc[1] =  +90.0;
+
+   /*  Reset viewport for rectangular image. */
+   if (large) {
+      cpgvstd();
+   } else {
+      cpgvsiz(1.0f, 3.0f, 1.0f, 3.0f);
+   }
+   cpgwnad (blc[0], trc[0], blc[1], trc[1]);
+
+   status = wcsini(1, 2, &wcs);
+
+   /* Set projection type to plate carree. */
+   strcpy(wcs.ctype[0], "RA---CAR");
+   strcpy(wcs.ctype[1], "DEC--CAR");
+
+   /* Reference pixel coordinates. */
+   wcs.crpix[0] = 0.0;
+   wcs.crpix[1] = 0.0;
+
+   /* Coordinate increments. */
+   wcs.cdelt[0] = -1.0;
+   wcs.cdelt[1] =  1.0;
+
+   /* Set parameters to draw the native grid. */
+   wcs.crval[0] = 0.0;
+   wcs.crval[1] = 0.0;
+
+   /* Annotation. */
+   strcpy(idents[0], "Right ascension");
+   strcpy(idents[1], "Declination");
+   strcpy(idents[2], "WCS plate caree projection");
+
+   opt[0] = 'G';
+   opt[1] = 'E';
+
+   /* Reduced size lettering. */
+   cpgsch(0.7f*scl);
+
+   /* Draw full grid lines. */
+   gcode[0] = 2;
+   gcode[1] = 2;
+
+   cpgsci(1);
+
+   grid1[0] = 0.0;
+   grid2[0] = 0.0;
+
+   ic = -1;
+   cpgsbox(blc, trc, idents, opt, 2121, 1212, c0, gcode, 0.0, 0, grid1, 0,
+      grid2, 1, pgwcsl_, 1, WCSLEN, 1, nlcprm, (int *)(&wcs), nldprm, 256,
+      &ic, cache, &ierr);
+
+   /* Draw the frame. */
+   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
+
+   cpgpage();
+
+  /*--------------------------------------------------------------------------
+   * Linear-linear plot with two types of alternative labelling.
+   *    - PGSBOX uses subroutine PGCRFN.
    *    - Separable (i.e. orthogonal), linear coordinate system.
    *    - Use of function PGCRFN for separable axis types.
    *    - Alternative labelling and axis annotation.
@@ -923,8 +996,8 @@ int main()
    opt[0] = ' ';
    opt[1] = ' ';
 
-   /* Normal size lettering. */
-   cpgsch(1.0*scl);
+   /* Reduced size lettering. */
+   cpgsch(0.8f*scl);
 
    /* Draw tick marks at the bottom for the first coordinate, grid lines  */
    /* for the second.  Setting GCODE[0] = -1 inhibits information being   */
@@ -989,20 +1062,19 @@ int main()
       0, pgcrfn_, 8, 2, 4, fcode[0], nliprm, nldprm, 256, &ic, cache, &ierr);
 
    /* Draw the frame. */
-   cpgbox("bc", 0.0, 0, "bc", 0.0, 0);
+   cpgbox("bc", 0.0f, 0, "bc", 0.0f, 0);
 
    cpgpage();
 
   /*--------------------------------------------------------------------------
-   *     Ninth example: Calendar axes using subroutine PGLBOX.
-   *     Features:
-   *        - Separable (i.e. orthogonal), linear coordinate system.
-   *        - Use of PGLBOX for simple linear axis types.
-   *        - Automatic choice of what edges to label; results in labelling
-   *          the bottom and left sides of the plot.
-   *        - Automatic choice of coordinate increments.
-   *        - Calendar date axis labelling.
-   *        - Single-character annotation on a vertical axis is upright.
+   * Calendar axes using subroutine PGLBOX.
+   *    - Separable (i.e. orthogonal), linear coordinate system.
+   *    - Use of PGLBOX for simple linear axis types.
+   *    - Automatic choice of what edges to label; results in labelling
+   *      the bottom and left sides of the plot.
+   *    - Automatic choice of coordinate increments.
+   *    - Calendar date axis labelling.
+   *    - Single-character annotation on a vertical axis is upright.
    *------------------------------------------------------------------------*/
 
    cpgswin(51900.0f, 52412.0f, 51900.0f, 57020.0f);
@@ -1016,7 +1088,7 @@ int main()
    opt[1] = 'Y';
 
    /* Reduced size lettering. */
-   cpgsch(0.7*scl);
+   cpgsch(0.7f*scl);
 
    /* Draw tick marks on each axis. */
    cpgsci(1);
@@ -1032,8 +1104,76 @@ int main()
    /* Draw the frame. */
    cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+   cpgpage();
+
+  /*--------------------------------------------------------------------------
+   * Simple linear axes.
+   *    - Simple linear axes handled by PGWCSL.
+   *    - Separable (i.e. orthogonal), linear coordinate system.
+   *    - Automatic choice of what edges to label; results in labelling
+   *      the bottom and left sides of the plot.
+   *    - Automatic choice of coordinate increments.
+   *    - Tick marks and labels at the edges of the frame.
+   *    - Single-character annotation on a vertical axis is upright.
+   *------------------------------------------------------------------------*/
+
+   naxis[0] = 3;
+   naxis[1] = 3;
+
+   blc[0] = 0.5;
+   blc[1] = 0.5;
+   trc[0] = naxis[0] + 0.5;
+   trc[1] = naxis[1] + 0.5;
+
+   status = wcsini(1, 2, &wcs);
+
+   strcpy(wcs.ctype[0], "x");
+   strcpy(wcs.ctype[1], "y");
+
+   /* Reference pixel coordinates. */
+   wcs.crpix[0] = 2.0;
+   wcs.crpix[1] = 2.0;
+
+   /* Coordinate increments. */
+   wcs.cdelt[0] = 1.0;
+   wcs.cdelt[1] = 1.0;
+
+   /* Spherical coordinate references. */
+   wcs.crval[0] = 2.0;
+   wcs.crval[1] = 2.0;
+
+   /* Annotation. */
+   strcpy(idents[0], "X");
+   strcpy(idents[1], "Y");
+   strcpy(idents[2], "");
+
+   opt[0] = ' ';
+   opt[1] = ' ';
+
+   /* Reduced size lettering. */
+   cpgsch(0.8f*scl);
+
+   /* Draw full grid lines. */
+   cpgsci(1);
+   gcode[0] = 1;
+   gcode[1] = 1;
+
+   grid1[0] = 0.0;
+   grid2[0] = 0.0;
+
+   ic = -1;
+   cpgsbox(blc, trc, idents, opt, 0, 0, c0, gcode, 2.0, 0, grid1, 0, grid2,
+      0, pgwcsl_, 1, WCSLEN, 1, nlcprm, (int *)(&wcs), nldprm, 256, &ic,
+      cache, &ierr);
+
+   /* Draw the frame. */
+   cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
+
+   cpgpage();
+
   /*------------------------------------------------------------------------*/
 
+   cpgask(0);
    cpgend();
 
    return 0;
